(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16397,        473]*)
(*NotebookOutlinePosition[     18162,        528]*)
(*  CellTagsIndexPosition[     18118,        524]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Summary", "Title",
  CounterAssignments->{{"Title", 3}}],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". The Variance Theorem"
}], "Section"],

Cell[TextData[
"Partial linear differential equations that lead to a Fourier convolution of \
an initial value distribution with a so-called propagator can easily be \
compared with measured data \[LongDash] for example for the temporal \
resolution of a density distribution, \[LongDash] in an analysis of \
variance."], "Text"],

Cell[TextData[{
  "The variance is calculated from the first three momenta of the order ",
  Cell[BoxData[
      \(m \[Element] {0, 1, 2}\)]],
  " of a distribution function. The calculation of momenta using the Laplace \
or Fourier transform of a distribution function is possible even if the \
solution function itself is not known. This procedure simplifies the analytic \
discussion significantly, because the variance of a solution propagator \
fundamentally belongs to a simpler class of functions than the solution \
propagator itself or even its Fourier convolution with the initial value \
distribution."
}], "Text"],

Cell[TextData[StyleBox[
"Basic to this procedure is the functional equation of variance (1.14):"]], 
  "Text"],

Cell[BoxData[
    \(\(\(\[Sigma]\^2\)[f*g] = \(\[Sigma]\^2\)[f] + \(\[Sigma]\^2\)[g], 
    \)\)], "Equation"],

Cell[TextData[{
  "which enables an adjusted variance ",
  Cell[BoxData[
      \(\(\[Sigma]\^2\)[t] - \(\[Sigma]\^2\)[t\_0]\)]],
  " of the measured data in comparison with the time difference ",
  Cell[BoxData[
      \(t - t\_0\)]],
  ". The result is to be compared with the variance of the propagator of the \
solution. The propagator of the solution starts at time ",
  Cell[BoxData[
      \(t = 0\)]],
  " as a Dirac delta distribution with zero variance."
}], "Text"],

Cell["\<\
In view of other comparisons between theory and measured data the \
analysis of variance has the advantage that a clear check of consistency is \
possible for any initial value distribution without making the mathematical \
effort too big.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". Delta Function"
}], "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "The Mellin transform opens the possibility for a less familiar approach to \
the delta distribution that is consistent with the theory of functions. In \
this way the delta distribution can again be called a delta function in the \
sense of the integral formula of Cauchy. The Mellin transform turns out to be \
a mighty general key in the field of function theory. Already in 1910 ",
  StyleBox["Mellin's theorem ",
    FontSlant->"Italic"],
  "(Mellin ",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]8, p. 323) proved the existence of the Dirac delta function \
(Dirac ",
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  ") for complex arguments. Representing the Dirac delta function as a Fox \
H-function (Fox ",
  ButtonBox["[Fox1961]",
    ButtonData:>{"Literatur.nb", "[Fox1961]"},
    ButtonStyle->"Hyperlink"],
  ", Mathai and Saxena ",
  ButtonBox["[MS1978]",
    ButtonData:>{"Literatur.nb", "[MS1978]"},
    ButtonStyle->"Hyperlink"],
  ") does not pose grave problems according to Dixon and Ferrar ",
  ButtonBox["[DF1936]",
    ButtonData:>{"Literatur.nb", "[DF1936]"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Since the work of Mellin ",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  " was published in German, neither the French distribution theory of \
Schwartz (see cite in ",
  ButtonBox["[Falk1966]",
    ButtonData:>{"Literatur.nb", "[Falk1966]"},
    ButtonStyle->"Hyperlink"],
  ", appendix IV, p. 98) nor the Indians (see ",
  ButtonBox["[MS1978]",
    ButtonData:>{"Literatur.nb", "[MS1978]"},
    ButtonStyle->"Hyperlink"],
  ", bibliography, p. 177: the German text is presented wrongly; the article \
quoted by Mellin [",
  ButtonBox["[Mel1910]",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  ", end of \[Section]1, p. 307] is not listed in their bibliography on p. \
177) nor the Americans have sufficiently internalized it. Even in Germany \
Mellin's work has receded into the background."
}], "Text"],

Cell["\<\
The delta function plays an important role in applying Laplace and \
Fourier transforms to fractional linear equations. This results in optimized \
fundamental systems of propagators that may eventually even contain the Green \
function of inhomogeneity.\
\>", "Text"],

Cell["\<\
The direct Mellin transform of a linear differential equation often \
results in a difference equation, the solution manifold of which can lead far \
beyond the Mellin transform of Fox H-functions.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". Anomalous Diffusion"
}], "Section"],

Cell[TextData[{
  "With this preparatory work the classification of diffusive processes is \
fairly easy. Diffusive processes have a variance which increases in a \
strictly monotonous way with time ",
  Cell[BoxData[
      \(t\)]],
  ". The variance of the diffusion propagator follows a power law in time ",
  Cell[BoxData[
      \(\(\[Sigma]\^2\)~\[Lambda]\ t\^\[Beta]\)]],
  ", where normal diffusion, according to the Einstein relation, is given by \
the power ",
  Cell[BoxData[
      \(\[Beta] = 1\)]],
  ". In the case of anomalous diffusion, subdiffusion (",
  Cell[BoxData[
      \(0 < \[Beta] < 1\)]],
  ") or superdiffusion (",
  Cell[BoxData[
      \(1 < \[Beta] < 2\)]],
  ") are characterized. The case ",
  Cell[BoxData[
      \(\[Beta] = 2\)]],
  " results in the variance of a wave equation."
}], "Text"],

Cell["\<\
Independently of whether a non-fractional diffusion equation is \
parabolic, elliptic or discrete, it is possible to postulate for the variance \
of the propagator at least the hypothesis of its proportionality with time, \
which means normal diffusion in the sense of the Einstein relation. The \
hyperbolic Cattaneo diffusion equation yields the variance of normal \
diffusion only asymptotically, for large times.\
\>", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "To model anomalous diffusion, the easiest solution is to utilize \
fractionalized Fick diffusion equations. In doing this, the combination of \
the time-fractional equation of Schneider and Wyss ",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  " with the space-fractional equation of Seshadri and West ",
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  " shows the advantage of the solution of Schneider and Wyss with its \
well-defined variance. A well-defined variance can also be calculated for the \
time- and space-fractional solutions by introducing finite limits of \
integration \[LongDash] however, the result is much more complicated than \
with Schneider and Wyss."
}], "Text"],

Cell["\<\
In order to describe radially symmetric systems without the \
appearance of negative densities for the propagator, the radially symmetric \
versions of the Fourier transform, of the Laplace operators and of the delta \
function should be adjusted to each other in such a way that an analytic \
reduction of the dynamical equation to just one dimension can be achieved \
with the help of the radially symmetric Fourier transform. Even though the \
functions that contain negative densities mathematically solve the respective \
equation, they nevertheless contradict the actual physics behind them in the \
sense that inconsistencies  have been proven to exist in setting up the \
equation or in solving it.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". Nuclear Magnetic Relaxation"
}], "Section"],

Cell[TextData[{
  "An application of the fractional diffusion equation of Schneider und Wyss \
has beed addressed for several dimensions of space. When calculating the \
correlation function ",
  Cell[BoxData[
      \(G[t]\)]],
  ", huge mathematical absurdities occur for the corresponding Fourier \
convolution in several dimensions. These, however, were consistently and \
elegantly avoided by Zavada and Kimmich ",
  ButtonBox["[ZK1998]",
    ButtonData:>{"Literatur.nb", "[ZK1998]"},
    ButtonStyle->"Hyperlink"],
  " in their discussion of the convolution integrals at the origin of the \
coodinate system ",
  Cell[BoxData[
      \(r = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The special setting ",
  Cell[BoxData[
      \(r = 0\)]],
  " for the Fourier convolution can be interpreted as the effect of the \
distribution for its expectation value. By this the resulting integrals of \
the correlation function ",
  Cell[BoxData[
      \(G[t]\)]],
  " are constructed in such a way that the power law of a fractal structure ",
  
  Cell[BoxData[
      \(g[r]~\(r\^\(H - 1\)\)\)]],
  " with the help of the similarity variable of the respective dynamical \
propagator can be transformed into a power law in time \[LongDash] and this \
with no dependance on the concrete shape of the propagator."
}], "Text"],

Cell[TextData[{
  "Comparing the theoretical formula with the power laws for a given \
frequency ",
  Cell[BoxData[
      \(\[Nu]\)]],
  " of NMR-spin-lattice relaxation times ",
  Cell[BoxData[
      \(T\_1\)]],
  " measured over several orders of magnitude, one finds that the actual \
physical transport processes can be classified as superdiffusive (i.e. \
abnormally fast)."
}], "Text"],

Cell["\<\
Here also the classification of diffusive theories is based on the \
variance theorem, leading to the circumstance that the propagator of the \
diffusive theory must yield a variance that has a power law in time. The \
diffusion theory of Schneider and Wyss has this property.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". Measuring Diffusion"
}], "Section",
  PageBreakAbove->True],

Cell["\<\
With the appropriate analytical and numeric effort it is possible \
to describe the Fourier convolution of two Fox H-functions. The Fourier \
convolution of the Gauss function and the Schneider/Wyss propagator yields an \
alternative to the Voigt profiles that is characterized by the fact that it \
has a well-defined variance.\
\>", "Text"],

Cell[TextData[StyleBox[
"The variance of a Fourier convolution of the Gauss function and the \
Schneider/Wyss propagator yields an important result, namely the additive \
behaviour of the variances of the convolution components. This result, of \
course, is in line with the variance theorem."]], "Text"],

Cell[TextData[{
  "The adjustment of variances makes it possible to precisely assess \
diffusive data. In doing this the two relevant parameters in anomalous \
diffusion, ",
  Cell[BoxData[
      \(\[Beta]\)]],
  " (time exponent) and ",
  Cell[BoxData[
      \(\[Lambda]\)]],
  " (generalized diffusion constant), can be deduced from a linear fit in a \
doubly logarithmic plot of the variance adjustment. This procedure of \
evaluation facilitates the work of the experimentator, especially if he or \
she does not know the mathematical background of the Fox H-function and its \
Fourier convolutions."
}], "Text"],

Cell[TextData[{
  "The measured data of Wei et al. ",
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  " on ",
  StyleBox["Single File Diffusion",
    FontSlant->"Italic"],
  " correspond well with the characteristics of subdiffusion (i.e. abnormally \
slow diffusion)."
}], "Text"],

Cell["\<\
With the calculation methods shown here, it is, in principle, \
possible to distinguish between two theories with identical properties of the \
variance of the propagator, but for the concrete case demonstrated here, we \
lack further and more accurate (driftless) experimental data.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". Computer Algebra"
}], "Section"],

Cell[TextData[{
  StyleBox[
  "It was possible to execute the calculations addressed here within a \
reasonable lapse of time due to the consistent use of computer algebra. As a \
\"by-product\" the "],
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  StyleBox[" software package for "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  " was developed. This enabled us not only to plot of Fox H-functions and \
their Fourier convolutions together with other functions, but also to write \
out all analytic calculations even in the fields of fractional \
differentiation of complex-valued order or of the frequently questioned delta \
function. Hereby the possibilities offered by the Mellin transform for \
solving dynamical equations or for consistently enlarging the theory of \
functions have not yet been exhausted."]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[CounterBox["Section"]],
  StyleBox[". Outlook"]
}], "Section",
  PageBreakAbove->True],

Cell["\<\
First steps towards a description of diffusive systems have been \
successfully taken, also for the case of anomalous diffusion. A whole series \
of additional studies can follow:\
\>", "Text"],

Cell["\<\
The discussion of diffusive automatic control systems, even if it \
is only a thermostat, has not yet been worked on.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
There is a lack of additional and more accurate (driftless) data on \
anomalous diffusion.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "The ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " software package for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can still be improved."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "The radially symmetric variants of Fourier transforms, delta functions and \
Laplace operators must be mutually adjusted for ",
  Cell[BoxData[
      \(d > 1\)]],
  " dimensions in such a way that they all fit together well."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
The applicability of the variance theorem to all linear differential \
equations of physics and engineering brings with it simplifying consequences \
which cannot yet be fathomed.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["", "Text",
  PageBreakAbove->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 742}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1248, 719},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->171,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Summary"}], "Header"]}, {Cell[ 
        TextData[ {"Summary"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 62, 1, 109, "Title",
  CounterAssignments->{{"Title", 3}}],

Cell[CellGroupData[{
Cell[1818, 56, 82, 3, 68, "Section"],
Cell[1903, 61, 329, 5, 72, "Text"],
Cell[2235, 68, 625, 11, 112, "Text"],
Cell[2863, 81, 110, 2, 32, "Text"],
Cell[2976, 85, 109, 2, 33, "Equation"],
Cell[3088, 89, 473, 12, 72, "Text"],
Cell[3564, 103, 263, 5, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3864, 113, 100, 4, 68, "Section",
  PageBreakAbove->True],
Cell[3967, 119, 1280, 31, 152, "Text"],
Cell[5250, 152, 918, 22, 112, "Text"],
Cell[6171, 176, 278, 5, 72, "Text"],
Cell[6452, 183, 221, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6710, 192, 81, 3, 68, "Section"],
Cell[6794, 197, 822, 23, 112, "Text"],
Cell[7619, 222, 464, 8, 92, "Text",
  PageBreakBelow->True],
Cell[8086, 232, 823, 16, 132, "Text"],
Cell[8912, 250, 730, 11, 152, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9679, 266, 89, 3, 68, "Section"],
Cell[9771, 271, 668, 17, 112, "Text"],
Cell[10442, 290, 648, 16, 112, "Text"],
Cell[11093, 308, 391, 11, 72, "Text"],
Cell[11487, 321, 300, 5, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11824, 331, 105, 4, 68, "Section",
  PageBreakAbove->True],
Cell[11932, 337, 352, 6, 72, "Text"],
Cell[12287, 345, 304, 4, 72, "Text"],
Cell[12594, 351, 616, 14, 112, "Text"],
Cell[13213, 367, 338, 10, 52, "Text"],
Cell[13554, 379, 307, 5, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13898, 389, 78, 3, 68, "Section"],
Cell[13979, 394, 863, 18, 152, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14879, 417, 113, 4, 68, "Section",
  PageBreakAbove->True],
Cell[14995, 423, 203, 4, 52, "Text"],
Cell[15201, 429, 180, 4, 52, "Text"],
Cell[15384, 435, 153, 4, 32, "Text"],
Cell[15540, 441, 243, 9, 32, "Text"],
Cell[15786, 452, 295, 7, 52, "Text"],
Cell[16084, 461, 242, 5, 52, "Text"],
Cell[16329, 468, 40, 1, 32, "Text",
  PageBreakAbove->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

